@@ -35,6 +35,16 @@ fn from_vec() {
     assert_eq!(m[&(1, 2)], 60);
 }
 
+#[test]
+fn to_vec() {
+    let mut m = Matrix::new(2, 2, 0usize);
+    m[&(0, 0)] = 0;
+    m[&(0, 1)] = 1;
+    m[&(1, 0)] = 10;
+    m[&(1, 1)] = 11;
+    assert_eq!(m.to_vec(), vec![0, 1, 10, 11]);
+}
+
 #[test]
 fn square_from_vec() {
     let m = Matrix::square_from_vec(vec![10, 20, 30, 40]);
